==> py4j-0.7.zip: py4j-0.7/py4j-java/test/py4j/reflection/MethodDescriptorTest.java <==
/*******************************************************************************
 * Copyright (c) 2009, 2011, Barthelemy Dagenais All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * - The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/
package py4j.reflection;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import org.junit.Test;

import p1.Cat;

public class MethodDescriptorTest {

	@Test
	public void testInternalRepresentation() {
		try {
			MethodDescriptor mDesc1 = new MethodDescriptor("meowmeow",
					Cat.class, new Class[] { String.class });
			MethodDescriptor mDesc2 = new MethodDescriptor("meowmeow",
					Cat.class, new Class[] { String.class });
			assertEquals(mDesc1, mDesc2);
			assertEquals(mDesc1.hashCode(), mDesc2.hashCode());
			assertEquals(mDesc1.getInternalRepresentation(),"p1.Cat.meowmeow(java.lang.String.)");
			assertEquals(mDesc1.toString(), "p1.Cat.meowmeow(java.lang.String.)");
		} catch (Exception e) {
			e.printStackTrace();
			fail();
		}
	}

}

==> py4j-0.8.1.zip: py4j-0.8.1/py4j-java/test/py4j/reflection/MethodDescriptorTest.java <==
/*******************************************************************************
 * Copyright (c) 2009, 2011, Barthelemy Dagenais All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * - The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/
package py4j.reflection;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import org.junit.Test;

import p1.Cat;

public class MethodDescriptorTest {

	@Test
	public void testInternalRepresentation() {
		try {
			MethodDescriptor mDesc1 = new MethodDescriptor("meowmeow",
					Cat.class, new Class[] { String.class });
			MethodDescriptor mDesc2 = new MethodDescriptor("meowmeow",
					Cat.class, new Class[] { String.class });
			assertEquals(mDesc1, mDesc2);
			assertEquals(mDesc1.hashCode(), mDesc2.hashCode());
			assertEquals(mDesc1.getInternalRepresentation(),
					"p1.Cat.meowmeow(java.lang.String.)");
			assertEquals(mDesc1.toString(),
					"p1.Cat.meowmeow(java.lang.String.)");
		} catch (Exception e) {
			e.printStackTrace();
			fail();
		}
	}

}
